@@ -3,7 +3,7 @@
 # modify it under the same terms as Perl itself.
 
 package Convert::ASN1;
-
+$Convert::ASN1::VERSION = '0.31';
 use strict;
 use Socket;
 
@@ -44,14 +44,14 @@ sub asn_recv { # $socket, $buffer, $flags
       }
     }
 
-    # If we can decode a tag and length we can detemine the length
+    # If we can decode a tag and length we can determine the length
     ($tb,$tmp) = asn_decode_tag(substr($buf,$pos));
     unless ($tb || $pos+$tb < length $buf) {
       next MORE if $n == length $buf;
       last MORE;
     }
 
-    if (ord(substr($buf,$pos+$tb,1)) == 0x80) {
+    if (unpack("C",substr($buf,$pos+$tb,1)) == 0x80) {
       # indefinite length, grrr!
       $depth++;
       $pos += $tb + 1;
@@ -138,7 +138,7 @@ sub asn_read { # $fh, $buffer, $offset
 	goto READ_ERR;
     }
 
-    my $tch = ord(substr($_[1],$pos++,1));
+    my $tch = unpack("C",substr($_[1],$pos++,1));
     # Tag may be multi-byte
     if(($tch & 0x1f) == 0x1f) {
       my $ch;
@@ -148,7 +148,7 @@ sub asn_read { # $fh, $buffer, $offset
 	  $e = sysread($_[0],$_[1],$n,length $_[1]) or
 	      goto READ_ERR;
 	}
-	$ch = ord(substr($_[1],$pos++,1));
+	$ch = unpack("C",substr($_[1],$pos++,1));
       } while($ch & 0x80);
     }
 
@@ -159,7 +159,7 @@ sub asn_read { # $fh, $buffer, $offset
 	  goto READ_ERR;
     }
 
-    my $len = ord(substr($_[1],$pos++,1));
+    my $len = unpack("C",substr($_[1],$pos++,1));
 
     if($len & 0x80) {
       unless ($len &= 0x7f) {
