@@ -5,10 +5,7 @@
 ;# modify it under the same terms as Perl itself.
 
 package Convert::ASN1::parser;
-{
-  $Convert::ASN1::parser::VERSION = '0.27';
-}
-
+$Convert::ASN1::parser::VERSION = '0.31';
 use strict;
 use Convert::ASN1 qw(:all);
 use vars qw(
@@ -754,7 +751,7 @@ sub compile_one {
         ;# do not contain duplicate tags
         ;#}
 	if ($op->[cTYPE] == opSET) {
-	  ;# In case we do CER encoding we order the SET elements by thier tags
+	  ;# In case we do CER encoding we order the SET elements by their tags
 	  my @tags = map { 
 	    length($_->[cTAG])
 		? $_->[cTAG]
@@ -785,7 +782,7 @@ sub compile {
   ;# once references have been resolved, and also due to
   ;# flattening of COMPONENTS, it is possible for an op
   ;# to appear in multiple places. So once an op is
-  ;# compiled we bless it. This ensure we dont try to
+  ;# compiled we bless it. This ensure we don't try to
   ;# compile it again.
 
   while(my($k,$v) = each %$tree) {
